@@ -1,7 +1,7 @@
 /*
  * Copyright 2003-2006 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
- * $Header: /var/cvsroot/gentoo-projects/pax-utils/paxelf.c,v 1.51 2006/07/30 18:02:00 vapier Exp $
+ * $Header: /var/cvsroot/gentoo-projects/pax-utils/paxelf.c,v 1.52 2006/12/11 03:31:54 vapier Exp $
  *
  * Copyright 2005-2006 Ned Ludd        - <solar@gentoo.org>
  * Copyright 2005-2006 Mike Frysinger  - <vapier@gentoo.org>
@@ -231,11 +231,23 @@ static pairtype elf_emtypes[] = {
 	QUERY(EM_ALPHA),
 	{ 0, 0 }
 };
-const char *get_elfemtype(int type)
+
+int get_emtype(elfobj *elf)
 {
-	return find_pairtype(elf_emtypes, type);
+	int type;
+	if (elf->elf_class == ELFCLASS32)
+		type = EGET(EHDR32(elf->ehdr)->e_machine);
+	else
+		type = EGET(EHDR64(elf->ehdr)->e_machine);
+	return type;
 }
 
+const char *get_elfemtype(elfobj *elf)
+{
+	return find_pairtype(elf_emtypes, get_emtype(elf));
+}
+
+
 /* translate elf PT_ defines */
 static pairtype elf_ptypes[] = {
 	QUERY(PT_NULL),
